pyprocessors_afp_entities — pyprocessors_afp_entities 0.1.0.dev0 documentation

# pyprocessors_afp_entities

AFPEntities annotations coming from different annotators

## Installation

You can simply `pip install pyprocessors_afp_entities`.

## Developing

### Pre-requesites

You will need to install `flit` (for building the package) and `tox` (for orchestrating testing and documentation building):

    python3 -m pip install flit tox

Clone the repository:

    git clone https://github.com/oterrier/pyprocessors_afp_entities

### Running the test suite

You can run the full test suite against all supported versions of Python (3.8) with:

    tox

### Building the documentation

You can build the HTML documentation with:

    tox -e docs

The built documentation is available at `docs/_build/index.html.